=========================
Google APIs common protos
=========================

googleapis-common-protos contains Python classes generated from the common
protos in the `api-common-protos`_ repository.

.. _`api-common-protos`: https://github.com/googleapis/api-common-protos
